@@ -4,8 +4,7 @@
   SPDX-License-Identifier: GPL-2.0-only
 */
 
-#ifndef FILTERACTIONMOVETEST_H
-#define FILTERACTIONMOVETEST_H
+#pragma once
 
 #include <QObject>
 
@@ -14,11 +13,10 @@ class FilterActionMoveTest : public QObject
     Q_OBJECT
 public:
     explicit FilterActionMoveTest(QObject *parent = nullptr);
-    ~FilterActionMoveTest();
+    ~FilterActionMoveTest() override;
 private Q_SLOTS:
     void shouldHaveSieveRequires();
     void shouldHaveRequiresPart();
     void shouldHaveDefaultValue();
 };
 
-#endif // FILTERACTIONMOVETEST_H
