@@ -4,8 +4,7 @@
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef MAILCOMMON_FILTERIMPORTER_FILTERIMPORTEREVOLUTION_P_H
-#define MAILCOMMON_FILTERIMPORTER_FILTERIMPORTEREVOLUTION_P_H
+#pragma once
 
 #include "filter/filterimporter/filterimporterabstract.h"
 
@@ -31,4 +30,3 @@ private:
 };
 }
 
-#endif // FILTERIMPORTEREVOLUTION_H
