@@ -4,8 +4,7 @@
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef ACCOUNTCONFIGORDERDIALOG_H
-#define ACCOUNTCONFIGORDERDIALOG_H
+#pragma once
 
 #include "mailcommon_export.h"
 #include <QDialog>
@@ -36,8 +35,7 @@ private:
     void writeConfig();
     void readConfig();
     void init();
-    AccountConfigOrderDialogPrivate *const d;
+    std::unique_ptr<AccountConfigOrderDialogPrivate> const d;
 };
 }
 
-#endif // ACCOUNTCONFIGORDERDIALOG_H
