@@ -4,12 +4,12 @@
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef RESOURCEREADCONFIGFILE_H
-#define RESOURCEREADCONFIGFILE_H
+#pragma once
 
 #include "mailcommon_export.h"
 #include <KConfigGroup>
 #include <QString>
+#include <memory>
 
 namespace MailCommon
 {
@@ -23,8 +23,7 @@ public:
     KConfigGroup group(const QString &name) const;
 
 private:
-    ResourceReadConfigFilePrivate *const d;
+    std::unique_ptr<ResourceReadConfigFilePrivate> const d;
 };
 }
 
-#endif // RESOURCEREADCONFIGFILE_H
